@@ -1,24 +1,40 @@
 import uuid
+from typing import Any, Dict
+
+
+def issue_to_v2(i: Dict[str, Any]) -> Dict[str, Any]:
+    """
+    Helper function to turn v1 issues into v2. Pretty similar formats
+    Some keys were removed, visible became mandatory
+    modifies the dict in place, redundant return
+    """
+    if "id" in i:
+        del i["id"]
+    if "issueId" in i:
+        del i["issueId"]
+    if "visible" not in i:
+        i["visible"] = True
+    return i
 
 
 def make_issue(
-        word: str,
-        start: int,
-        end: int,
-        issue_type: str,
-        score,
-        simpleDescription: str,
-        description="",
-        suggestions=[],
-        subCategory="",
-        learnMore="",
-        paragraph=False,
-        header="",
-        metaDict={},
-        accept_all_changes=False,
-        debug=False,
-        segment=None,
-        visible=True
+    word: str,
+    start: int,
+    end: int,
+    issue_type: str,
+    score,
+    simpleDescription: str,
+    description="",
+    suggestions=[],
+    subCategory="",
+    learnMore="",
+    paragraph=False,
+    header="",
+    metaDict={},
+    accept_all_changes=False,
+    debug=False,
+    segment=None,
+    visible=True,
 ):
     """
     reference:
@@ -43,7 +59,7 @@ def make_issue(
         "description": description,
         "simpleDescription": simpleDescription,
         "meta": {"paragraph": paragraph},
-        "visible": visible
+        "visible": visible,
     }
 
     if subCategory:
@@ -63,12 +79,18 @@ def make_issue(
         common = [value for value in metaDict.keys() if value in issue["meta"]]
         for c in common:
             if metaDict[c] != issue["meta"][c]:
-                print(f"Meta_dict {c}:{metaDict[c]} is overwriting issue meta {c}:{issue['meta'][c]}")
+                print(
+                    f"Meta_dict {c}:{metaDict[c]} is overwriting issue meta {c}:{issue['meta'][c]}"
+                )
 
         if segment is not None:
-            suggestion = suggestions[0] if len(suggestions) else ''
-            issue['new_segment'] = segment[:start] + suggestion + segment[end:]
+            suggestion = suggestions[0] if len(suggestions) else ""
+            issue["new_segment"] = segment[:start] + suggestion + segment[end:]
 
     issue["meta"].update(metaDict)
 
     return issue
+
+
+def make_issue_v2(*args, **kwargs):
+    return issue_to_v2(make_issue(*args, **kwargs))
