@@ -80,7 +80,7 @@ async def v2(instance, request):
         # get segment and other needed values
         segment = el["content"]["segment"]
         s_id = el["content"]["segmentId"]
-        meta = el["meta"]
+        meta = el.get("meta", {})
         category = el["category"]
         # trust that BE only sends if they want what we do
         segment_response = {"category": category, "segmentId": s_id}
